"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const postProcessUnionTypes_1 = require("./postProcessUnionTypes");
function postProcessServiceOperations(service, client, useUnionTypes = false) {
    const names = new Map();
    return service.operations.map(operation => {
        const clone = { ...operation };
        // Parse the service parameters and results, very similar to how we parse
        // properties of models. These methods will extend the type if needed.
        clone.parameters = clone.parameters.map(parameter => postProcessUnionTypes_1.postProcessUnionTypes(parameter, client, useUnionTypes));
        clone.results = clone.results.map(result => postProcessUnionTypes_1.postProcessUnionTypes(result, client, useUnionTypes));
        clone.imports.push(...clone.parameters.flatMap(parameter => parameter.imports));
        clone.imports.push(...clone.results.flatMap(result => result.imports));
        // Check of the operation name
        const name = clone.name;
        const index = names.get(name) || 0;
        if (index > 0) {
            clone.name = `${name}${index}`;
        }
        names.set(name, index + 1);
        return clone;
    });
}
exports.postProcessServiceOperations = postProcessServiceOperations;
