"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const Handlebars = require("handlebars");
const path = require("path");
const readHandlebarsTemplate_1 = require("./readHandlebarsTemplate");
const registerHandlebarHelpers_1 = require("./registerHandlebarHelpers");
function resolveTemplate(filePath) {
    return path.resolve(__dirname, `../../src/templates/${filePath}`);
}
/**
 * Read all the Handlebar templates that we need and return on wrapper object
 * so we can easily access the templates in out generator / write functions.
 */
function readHandlebarsTemplates() {
    registerHandlebarHelpers_1.registerHandlebarHelpers();
    const templates = {
        index: readHandlebarsTemplate_1.readHandlebarsTemplate(resolveTemplate('index.hbs')),
        model: readHandlebarsTemplate_1.readHandlebarsTemplate(resolveTemplate('model.hbs')),
        schema: readHandlebarsTemplate_1.readHandlebarsTemplate(resolveTemplate('schema.hbs')),
        service: readHandlebarsTemplate_1.readHandlebarsTemplate(resolveTemplate('service.hbs')),
        settings: readHandlebarsTemplate_1.readHandlebarsTemplate(resolveTemplate('core/OpenAPI.hbs')),
    };
    const partials = [
        'exportEnum.hbs',
        'exportInterface.hbs',
        'exportType.hbs',
        'extends.hbs',
        'isNullable.hbs',
        'isReadOnly.hbs',
        'isRequired.hbs',
        'parameters.hbs',
        'result.hbs',
        'schema.hbs',
        'schemaArray.hbs',
        'schemaDictionary.hbs',
        'schemaEnum.hbs',
        'schemaGeneric.hbs',
        'schemaInterface.hbs',
        'type.hbs',
        'typeArray.hbs',
        'typeDictionary.hbs',
        'typeEnum.hbs',
        'typeGeneric.hbs',
        'typeInterface.hbs',
        'typeReference.hbs',
    ];
    partials.forEach(partial => {
        const templatePath = resolveTemplate(`partials/${partial}`);
        const templateName = path.basename(partial, '.hbs');
        const template = readHandlebarsTemplate_1.readHandlebarsTemplate(templatePath);
        Handlebars.registerPartial(templateName, template);
    });
    return templates;
}
exports.readHandlebarsTemplates = readHandlebarsTemplates;
